window.Gleam.initSearch([{"doc":"check_maybe_div_by_zero","title":"check_maybe_div_by_zero","content":"# Check Maybe Div By Zero for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/check_maybe_div_by_zero)](https://hex.pm/packages/check_maybe_div_by_zero)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/check_maybe_div_by_zero/)\n\nGleam does not crash on division by zero.\n\nIn effect any literal division by zero in gleam returns a zero. You may opt to\nuse the stdlib&#39;s `int.divide`, `int.modulo`, `int.remainder`, `float.divide` and\n`float.modulo` to catch errors instead of assmuing 0.\n\nSee following explanations why and what happens:\n- &lt;https://tutorial.ponylang.io/gotchas/divide-by-zero.html&gt;\n- &lt;https://www.hillelwayne.com/post/divide-by-zero/&gt;\n\n## What does this do\n\nThis helper checks gleam code for potential(!) literal division by zero.\nIt may be 100% fine to run `1 / a` if you know that `a` is never zero.\nIt may also be fine to run `1 / a` where `a` equals `0` depending on your\nrequirements.\n\nThis checker is for when this is not fine. It allows you to check a code\nrepository for POTENTIAL literal divison by zero in gleam-land (it does NOT\ncheck Erlang or JS FFI).\n\n## Installation\n\n```sh\ngleam add check_maybe_div_by_zero@1\n```\n\n## Usage\n\n```sh\ngleam run --module check_maybe_div_by_zero\n# or explicitly define the src dir to check:\ngleam run --module check_maybe_div_by_zero -- src\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/check_maybe_div_by_zero&gt;.\n\n## CI Integration\n\nYou may run `gleam run --module check_maybe_div_by_zero` which returns `exit(0)`\nif no potential division by zero is found, and `exit(1)` if a potential division\nby zero is found. It should thus stop the CI in case a divison by zero is found.\n\n```\njobs:\n  test-and-no-div-zero:\n    runs-on: ubuntu-latest\n    steps:\n      - uses: actions/checkout@v4\n      - uses: erlef/setup-beam@v1\n        with:\n          otp-version: &quot;27.0.1&quot;\n          gleam-version: &quot;1.3.2&quot;\n          rebar3-version: &quot;3&quot;\n      - run: gleam deps download\n      - run: gleam format --check src test\n      - run: gleam test\n      - run: gleam run --module check_maybe_div_by_zero -- src\n      - run: gleam test --target javascript\n      - run: gleam run --module check_maybe_div_by_zero --target javascript -- src\n```\n\n## Targets\n\n- Erlang\n- NodeJS\n- Deno\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"check_maybe_div_by_zero","title":"has_mod_literal_div","content":"pub fn has_mod_literal_div(filepath: String) -&gt; Bool\n\nSynonyms:\ncheck_maybe_div_by_zero.has_mod_literal_div\ncheck_maybe_div_by_zero has_mod_literal_div","url":"check_maybe_div_by_zero.html#has_mod_literal_div"},{"doc":"check_maybe_div_by_zero","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ncheck_maybe_div_by_zero.main\ncheck_maybe_div_by_zero main","url":"check_maybe_div_by_zero.html#main"},{"doc":"check_maybe_div_by_zero","title":"mods_with_literal_div","content":"pub fn mods_with_literal_div(in src_dir: String) -&gt; Int\n\nSynonyms:\ncheck_maybe_div_by_zero.mods_with_literal_div\ncheck_maybe_div_by_zero mods_with_literal_div","url":"check_maybe_div_by_zero.html#mods_with_literal_div"},{"doc":"check_maybe_div_by_zero","title":"run","content":"pub fn run(in path: String) -&gt; Nil\n\nSynonyms:\ncheck_maybe_div_by_zero.run\ncheck_maybe_div_by_zero run","url":"check_maybe_div_by_zero.html#run"},{"doc":"check_maybe_div_by_zero","title":"check_maybe_div_by_zero","content":"","url":"check_maybe_div_by_zero.html"}]);